@@ -5,6 +5,10 @@ from djangoldp_conversation.models import Conversation
 from djangoldp.models import Model
 from djangoldp_skill.models import Skill
 
+job_fields = ["@id", "author", "title", "description", "creationDate", "skills", "closingDate", "conversation"]
+if 'djangoldp_community' in settings.DJANGOLDP_PACKAGES:
+    job_fields += ['community']
+
 
 class JobOffer(Model):
     author = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='jobOffers', on_delete=models.CASCADE)
@@ -23,6 +27,7 @@ class JobOffer(Model):
         authenticated_perms = ["inherit", "add"]
         owner_perms = ["inherit", "change", "delete"]
         container_path = 'job-offers/'
+        serializer_fields = job_fields
         rdf_type = 'hd:joboffer'
 
     def __str__(self):
